@@ -23,7 +23,6 @@
 #include <config.h>
 #include <string.h>
 #include "gtk-utils.h"
-#include <libgnome/gnome-help.h>
 
 #define LOAD_BUFFER_SIZE 65536
 
@@ -438,7 +437,8 @@ _gtk_error_dialog_new (GtkWindow        *parent,
 		/* Expander */
 
 		expander = gtk_expander_new_with_mnemonic (_("Command _Line Output"));
-
+		gtk_expander_set_expanded (GTK_EXPANDER (expander), secondary_text == NULL);
+		
 		/* Add text */
 
 		scrolled = gtk_scrolled_window_new (NULL, NULL);
@@ -753,16 +753,7 @@ show_uri (GdkScreen   *screen,
 {
 	gboolean result;
 
-#ifndef GTK_2_13
-	GAppLaunchContext *app_context;
-
-	app_context = g_app_launch_context_new ();
-	result = g_app_info_launch_default_for_uri (uri, G_APP_LAUNCH_CONTEXT (app_context), error);
-
-	g_object_unref (app_context);
-#else
 	result = gtk_show_uri (screen, uri, timestamp, error);
-#endif
 
 	return result;
 }
@@ -800,3 +791,30 @@ show_help_dialog (GtkWindow  *parent,
 	}
 	g_free (uri);
 }
+
+
+GtkBuilder * 
+_gtk_builder_new_from_file (const char *ui_file)
+{
+	char       *filename;
+	GtkBuilder *builder;
+	GError     *error = NULL;
+
+	filename = g_build_filename (UI_DIR, ui_file, NULL);
+	builder = gtk_builder_new ();
+        if (! gtk_builder_add_from_file (builder, filename, &error)) {
+                g_warning ("%s\n", error->message);
+                g_clear_error (&error);
+        }
+	g_free (filename);
+	        
+        return builder;
+}
+
+
+GtkWidget * 
+_gtk_builder_get_widget (GtkBuilder *builder,
+			 const char *name)
+{
+	return (GtkWidget *) gtk_builder_get_object (builder, name);
+}
